@@ -21,6 +21,10 @@
 #'   Target coordinate reference system.
 #' @param extent 'bbox' object.
 #'   Spatial extent (aka bounding box) used to crop the simple feature.
+#' @param type 'character' vector.
+#'   For retured geometries of type "GEOMETRY" or "GEOMETRYCOLLECTION",
+#'   the returned object will consist only of elements of the specified type,
+#'   one of "POLYGON", "POINT", and "LINESTRING".
 #'
 #' @return Returns an object of class 'sf'.
 #'
@@ -34,7 +38,8 @@ clean_sf <- function(x,
                      cols = NULL,
                      agr = NULL,
                      crs = NULL,
-                     extent = NULL) {
+                     extent = NULL,
+                     type = NULL) {
 
   # check arguments
   checkmate::assert_multi_class(x, classes = c("sf", "data.frame"))
@@ -52,6 +57,7 @@ clean_sf <- function(x,
   )
   checkmate::assert_class(crs, classes = "crs", null.ok = TRUE)
   checkmate::assert_class(extent, classes = "bbox", null.ok = TRUE)
+  checkmate::assert_subset(type, choices = c("POLYGON", "POINT", "LINESTRING"))
 
   # make valid
   sp <- sf::st_make_valid(x)
@@ -88,15 +94,22 @@ clean_sf <- function(x,
     bb <- sf::st_as_sfc(extent) |>
       sf::st_transform(crs = sf::st_crs(sp)) |>
       sf::st_bbox()
-    sp <- sf::st_crop(sp, bb)
+    sp <- suppressWarnings(sf::st_crop(sp, bb))
   }
 
-  # check validity
-  sf::st_is_valid(sp) |>
-    stopifnot()
+  # extract specified element types
+  if (!is.null(type)) {
+    is <- c("GEOMETRY", "GEOMETRYCOLLECTION") %in% sf::st_geometry_type(sp)
+    if (any(is)) {
+      sp <- sf::st_collection_extract(sp, type = type)
+    }
+  }
 
   # clear row names
   rownames(sp) <- NULL
 
+  # make valid
+  sp <- sf::st_make_valid(sp)
+
   sp
 }
